---
title: Hints
---

# Hints

<div class="documentation__toc"></div>

## Introduction

Path hints are unique prefixes used when specifying various resources. The path hint represents a directory.

```php
echo $asset->path('public::css/styles.css');

// /var/my_site/public/app/assets/theme/css/styles.css
```

> All listed hints are relative to your application's root directory.{.notice}


## Asset Hints

Asset hints can be used to hint the location of files consumed by the [Asset](../core-concepts/asset) pipeline.

```twig
{{ asset_add('styles.css', 'streams::ui/form.css') }}
```

```php
$asset->add('styles.css', 'streams::ui/form.css');
```

### addons

Every addon has an asset path hint for the addon's `resources` directory `{addon_path}/resources/` which looks like `anomaly.module.documentation::`.

### public

The `public::` path hint represents the `public/` directory.

### node

The `node::` path hint represents the `node_modules/` directory where assets are downloaded by `npm`.

### bower

The `bower::` path hint represents the `bin/bower_components/` directory where assets are downloaded by `bower`.

### asset

The `asset::` path hint represents your application's asset cache directory `public/app/{application}/`.

### shared

The `shared::` path hint represents your the base resources directory `resources/`.

### resources

The `resources::` path hint represents your application's resources directory `resources/{application}/`.

### storage

The `storage::` path hint represents your application's storage directory `storage/streams/{application}/`.

### streams

The `streams::` path hint represents the `resources` directory for the Streams Platform `vendor/anomaly/streams-platform/resources/`.

### module

The `module::` path hint represents the `resources` directory for the `active` module `{active_module_path}/resources/`.

### theme

The `theme::` path hint represents the `resources` directory for the `active` theme `{active_theme_path}/resources/`.


## Image Hints

Image hints can be used to hint the location of images consumed by the [Image](../core-concepts/image) management system.

```twig
{{ img('theme::img/logo.svg')|raw }}
```

```php
$image->make('theme::img/logo.svg')->path();
```

### addons

Every addon has an image path hint for the addon's `resources` directory `{addon_path}/resources/` which looks like `anomaly.module.documentation::`.

### module

The `module::` path hint represents the `resources` directory for the `active` module `{active_module_path}/resources/`.

### theme

The `theme::` path hint represents the `resources` directory for the `active` theme `{active_theme_path}/resources/`.

### public

The `public::` path hint represents the `public/` directory.

### node

The `node::` path hint represents the `node_modules/` directory where assets are downloaded by `npm`.

### bower

The `bower::` path hint represents the `bin/bower_components/` directory where assets are downloaded by `bower`.

### asset

The `asset::` path hint represents your application's asset cache directory `public/app/{application}/`.

### resources

The `resources::` path hint represents your application's resources directory `resources/{application}/`.

### storage

The `storage::` path hint represents your application's storage directory `storage/streams/{application}/`.

### streams

The `streams::` path hint represents the `resources` directory for the Streams Platform `vendor/anomaly/streams-platform/resources/`.


## Config Hints

Configuration hints can be used to hint [configuration values](../core-concepts/config).

```twig
{{ config('streams::datetime.date_format') }}
```

```php
config('streams::datetime.date_format');
```

### addons

Every addon has a config path hint for the addon's `config` directory `{addon_path}/resources/config/` which looks like `anomaly.module.documentation::`. 

### streams

The `streams::` path hint represents the `config` directory for the Streams Platform `vendor/anomaly/streams-platform/resources/config/`.


## Translator Hints

Translator hints can be used to hint [translation string keys](../core-concepts/translater).

```twig
{{ trans('streams::distribution.name') }}
```

```php
trans('streams::distribution.name');
```

### addons

Every addon has a config path hint for the addon's `lang` directory `{addon_path}/resources/lang/` which looks like `anomaly.module.documentation::`. 

### module

The `module::` path hint represents the `lang` directory for the `active` module `{active_module_path}/resources/lang/`.

### theme

The `theme::` path hint represents the `lang` directory for the `active` theme `{active_theme_path}/resources/lang/`.

### streams

The `streams::` path hint represents the `lang` directory for the Streams Platform `vendor/anomaly/streams-platform/resources/lang/`.


## View Hints

View hints can be used to hint [view](../core-concepts/views) files.

```twig
{{ view('streams::form.form') }}
```

```php
view('streams::form.form');
```

### addons

Every addon has a path hint for the addon's `view` directory `{addon_path}/resources/views/` which looks like `anomaly.module.documentation::`. 

### module

The `module::` path hint represents the `views` directory for the `active` module `{active_module_path}/resources/views/`.

### theme

The `theme::` path hint represents the `views` directory for the `active` theme `{active_theme_path}/resources/views/`.

### streams

The `streams::` path hint represents the `views` directory for the Streams Platform `vendor/anomaly/streams-platform/resources/views/`.

### app

The `app::` path hint represents the `views` directory within your application's resrouces directory `resources/{application}/views/`.

### published

The `published::` path hint represents the `addons override` directory within your application's resrouces directory `resources/{application}/addons/`. Paths using this hint will usually look like this: `published::anomaly/posts-module/views/posts/view.twig`.

### storage

The `storage::` path hint represents the `views` directory within your application's storage directory `/storage/streams/{application}/`.

### shared

The `shared::` path hint represents the `views` directory within the resources directory `/resources/views/`.
